#!/bin/bash

# Convert ligand topology from CHARMM to GROMACS and combine it with protein's.
# Requires both `module load gromacs/5.1.4` and `mamba activate gromacs-topol`.
# Also presumes that ppi_fix.mol2 and ppi_fix.str are already generated,
# say with the CGenFF web interface. (They also have to be named PPI! Not
# ppi.pdb.)

#for d in test/; do
for d in *ps/; do
  # I use the python=3.7 and networkx=2.3 version of the script
  cp cgenff_charmm2gmx_py3_nx2.py $d
  cd $d;

  # Create GROMACS topology files for ligand. 
  # Requires NetworkX version 2.3 and Python 3.7.3 (mamba environment gromacs-topol)
  # Also note: ppi.pdb line in both ppi_fix.mol2 and ppi_fix.str must be
  # changed to PPI
  python cgenff_charmm2gmx_py3_nx2.py PPI ppi_fix.mol2 ppi_fix.str charmm36-jul2022.ff

  # Convert the ligand PDB to a GROMACS coordinate file
  gmx editconf -f ppi_ini.pdb -o ppi.gro

  # Combine protein and ligand GROMACS coordinate files
  cp protein.gro protein_and_ligand.gro
  boxvec=$(tail -n1 protein_and_ligand.gro)         # save sim. box vectors
  sed -i '$ d' protein_and_ligand.gro               # remove box vectors
  sed -i '2s/4836/4846/g' protein_and_ligand.gro    # increment num. of atoms 
  sed -n '3,12p' ppi.gro >> protein_and_ligand.gro  # add ligand coords
  echo $boxvec >> protein_and_ligand.gro            # restore sim. box vectors

  # Modify topol.top, the main topology wrapper
  # The 'endif' is because it only occurs in the posre.itp block, after which
  #   we want to insert #include "ppi.itp". Not super safe/transferable!
  #   Check if redoing for more than just protein + ligand!!
  sed -i '/forcefield.itp/a ; Include ligand parameters\n#include "ppi.prm"' topol.top
  sed -i '/endif/a ; Include ligand topology\n#include "ppi.itp"' topol.top
  echo "PPI                 1" >> topol.top

  cd ../
done
