#!/bin/bash

# Generate the protein topology.
# Requires `module load gromacs/5.1.4` to have been called already.

#for d in *ps/; do
for d in test/; do
  cd $d;

  # Separate pdb files for protein and ligand
  for f in samples*.pdb; do
    cp $f protein.pdb
    grep 'PPI' $f > ppi.pdb
    sed -i '/PPI/d' protein.pdb

    # Build GROMACS topology for protein:
    #   no water model (-water none)
    #   CHARMM36(m) forcefield (-ff charmm36-jul2022)
    #   ionized terminal residues (this is the default)
    gmx pdb2gmx -f protein.pdb -o protein.gro -water none -ff charmm36-jul2022

    # Now convert ligand file to Mol2
    obabel -ipdb ppi.pdb -omol2 > ppi.mol2
    sed -i 's/\*\+/PPI/g' ppi.mol2
    sed -i 's/ppi.pdb/PPI    /g' ppi.mol2

    cp ../sort_mol2_bonds.pl .
    perl sort_mol2_bonds.pl ppi.mol2 ppi_fix.mol2
  done
  cd ../
done


